@@ -23,10 +23,19 @@ pibble_tidy_samples<- function(m, use_names=FALSE, as_factor=FALSE){
                                                      .data$coord, 
                                                      .data$sample, 
                                                      .data$iter)
-  if (!is.null(m$Lambda)) l$Lambda <- gather_array(m$Lambda, .data$val, 
-                                                           .data$coord, 
-                                                           .data$covariate, 
-                                                           .data$iter)
+  if (!is.null(m$Lambda)){
+    if(typeof(m$Lambda) == "list"){
+      l$Lambda <- lapply(m$Lambda, FUN = function(x){gather_array(x, .data$val, 
+                                                                  .data$coord, 
+                                                                  .data$covariate, 
+                                                                  .data$iter)})
+    } else{
+      l$Lambda <- gather_array(m$Lambda, .data$val, 
+                               .data$coord, 
+                               .data$covariate, 
+                               .data$iter)
+    }
+  } 
   if (!is.null(m$Sigma)) l$Sigma <- gather_array(m$Sigma, .data$val, 
                                                          .data$coord, 
                                                          .data$coord2, 
@@ -121,19 +130,6 @@ summary_check_precomputed <- function(m, pars){
 }
 
 
-#' Summarise pibblefit or orthusfit object and print posterior quantiles
-#' 
-#' Default calculates median, mean, 50\% and 95\% credible interval
-#' 
-#' @param object an object of class pibblefit or orthusfit
-#' @param ... other objects to be passed to `summary.pibblefit` or `summary.orthusfit`
-#' @return A list if class is `pibblefit` or `orthusfit`
-#' @export 
-summary <- function(object, ...){
-  UseMethod("summary")
-}
-
-
 #' Summarise pibblefit object and print posterior quantiles
 #' 
 #' Default calculates median, mean, 50\% and 95\% credible interval
@@ -285,22 +281,6 @@ summary.orthusfit <- function(object, pars=NULL, use_names=TRUE, as_factor=FALSE
 }
 
 
-#' Print dimensions and coordinate system information for an orthusfit or pibblefit object. 
-#'
-#' @param x an object of class pibblefit or orthusfit
-#' @param ... other arguments to pass to summary function
-#' @return No direct value, but a print out
-#' @export
-#' @examples 
-#' sim <- pibble_sim()
-#' fit <- pibble(sim$Y, sim$X)
-#' print(fit)
-#' 
-print <- function(x, ...){
-  UseMethod("print")
-}
-
-
 #' Print dimensions and coordinate system information for pibblefit object. 
 #'
 #' @param x an object of class pibblefit
@@ -403,25 +383,6 @@ print.orthusfit <- function(x, summary=FALSE, ...){
 }
 
 
-#' Return regression coefficients of pibblefit or orthusfit object
-
-#' 
-#' @param object an object of class pibblefit or orthusfit
-#' @param ... other options passed to coef.pibblefit  or coef.orthusfit (see details)
-#' @return Array of dimension (D-1) x Q x iter
-#'
-#' @export
-#' @examples 
-#' sim <- pibble_sim()
-#' fit <- pibble(sim$Y, sim$X)
-#' coef(fit)
-#' 
-coef <- function(object, ...){
-  UseMethod("coef")
-}
-
-
-
 #' Return regression coefficients of pibblefit object
 #' 
 #' Pibble: Returned as array of dimension (D-1) x Q x iter (if in ALR or ILR) otherwise
@@ -442,6 +403,8 @@ coef.pibblefit <- function(object, ...){
   args <- list(...)
   use_names <- args_null("use_names", args, TRUE)
   
+  if(typeof(object$Lambda) == "list") stop("Not currently supported for additive basset model.")
+  
   if (is.null(object$Lambda)) stop("pibblefit object does not contain samples of Lambda")
   x <- object$Lambda
   if (use_names) return(name_array(x, object, list("cat", "cov", NULL)))
@@ -476,18 +439,6 @@ coef.orthusfit <- function(object, ...){
 
 
 
-#' Generic method to convert to list
-#' 
-#' @param x An object of class pibblefit or orthusfit
-#' @param ... Other objects to pass
-#' 
-#' @return A list object
-#' @export
-as.list <- function(x, ...){
-  UseMethod("as.list")
-}
-
-
 #' Convert object of class pibblefit to a list
 #' 
 #' @param x an object of class pibblefit
@@ -516,27 +467,6 @@ as.list.orthusfit <- function(x,...){
 
 
 
-#' Predict response from new data
-#' 
-#' 
-#' @param object An object of class pibblefit
-#' @param ... Other objects to be passed to the `predict` function
-#' 
-#' @return (if summary==FALSE) array D x N x iter; (if summary==TRUE) 
-#' tibble with calculated posterior summaries 
-#' 
-#' @export
-#' @importFrom stats median predict runif
-#' @examples 
-#' sim <- pibble_sim()
-#' fit <- pibble(sim$Y, sim$X)
-#' predict(fit)[,,1:2] # just show 2 samples
-predict <- function(object, ...){
-  UseMethod("predict")
-}
-
-
-
 #' Predict response from new data
 #' 
 #' 
@@ -620,7 +550,7 @@ predict.pibblefit <- function(object, newdata=NULL, response="LambdaX", size=NUL
   if (is.null(object$Lambda)) stop("pibblefit object does not contain samples of Lambda")
   LambdaX <- array(0, dim = c(object$D-1, nnew, iter))
   for (i in 1:iter){
-    LambdaX[,,i] <- object$Lambda[,,i] %*% newdata
+    LambdaX[,,i] <- drop(object$Lambda[,,i, drop = FALSE]) %*% newdata
   }
   if (use_names) LambdaX <- name_array(LambdaX, object,
                                        list("cat", colnames(newdata), 
@@ -644,6 +574,9 @@ predict.pibblefit <- function(object, newdata=NULL, response="LambdaX", size=NUL
   # Draw Eta
   Eta <- array(0, dim=dim(LambdaX))
   zEta <- array(rnorm((object$D-1)*nnew*iter), dim = dim(Eta))
+  if(is.null(object$Sigma)){
+    print("Sigma is needed to predict either Eta or Y.")
+  }
   for (i in 1:iter){
     Eta[,,i] <- LambdaX[,,i] + t(chol(object$Sigma[,,i]))%*%zEta[,,i]
   }
@@ -673,6 +606,14 @@ predict.pibblefit <- function(object, newdata=NULL, response="LambdaX", size=NUL
     Pi <- to_proportions(as.pibblefit(object[com]))$Eta
   }
   Ypred <- array(0, dim=c(object$D, nnew, iter))
+  
+  # Fixing small bug. If newdata is a single sample, then size will be a vector.
+  # The loop with rmultinom will break as a result unless size is transformed to a matrix.
+  
+  if(is.vector(size)){
+    size <- matrix(size, nrow = 1)
+  }
+
   for (i in 1:iter){
     for (j in 1:nnew){
       Ypred[,j,i] <- rmultinom(1, size=size[j,i], prob=Pi[,j,i])
@@ -828,6 +769,7 @@ sample_prior.pibblefit <- function(m, n_samples=2000L,
                                     pars=c("Eta", "Lambda", "Sigma"), 
                                     use_names=TRUE, ...){
   req(m, c("upsilon", "Theta", "Gamma", "Xi"))
+  if(typeof(m$Theta) == "list") stop("Function not currently supported for additive basset model.")
   
   # Convert to default ALR for computation
   l <- store_coord(m)
